Module: Google::Apis::FtpV1
- Defined in:
- lib/google/apis/ftp_v1.rb,
lib/google/apis/ftp_v1/classes.rb,
lib/google/apis/ftp_v1/service.rb,
lib/google/apis/ftp_v1/gem_version.rb,
lib/google/apis/ftp_v1/representations.rb
Overview
Cloud FTP API
Cloud FTP is a managed service that allows transferring files directly to Google Cloud Storage using SFTP.
Defined Under Namespace
Classes: AllowedConsumer, CancelOperationRequest, CloudFTPService, DeniedConsumer, Empty, ExternalServerConfig, InternalServerConfig, ListLocationsResponse, ListOperationsResponse, ListServersResponse, ListUsersResponse, Location, Operation, OperationMetadata, PscEndpoint, Server, ServerCredential, StartServerRequest, Status, StopServerRequest, StorageDirectoryMapping, User, UserCredential
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-ftp_v1 gem
"0.1.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20260729"- VERSION =
Version of the Cloud FTP API this client connects to. This is NOT the gem version.
'V1'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'