Class: Google::Apis::FtpV1::ExternalServerConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ftp_v1/classes.rb,
lib/google/apis/ftp_v1/representations.rb,
lib/google/apis/ftp_v1/representations.rb

Overview

Configuration for external server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalServerConfig

Returns a new instance of ExternalServerConfig.



122
123
124
# File 'lib/google/apis/ftp_v1/classes.rb', line 122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_cidr_blocksArray<String>

Optional. List of CIDR blocks that are allowed to access the Server. A CIDR range consists of an IP Address and a prefix length to construct the subnet mask. By default, the prefix length is 32 (i.e. matches a single IP address). For now, only IPV4 addresses are supported. Examples: "203.0.113.0/24" - matches with the IP addresses in the range 203.0.113.0 - 203.0.113.255. "0.0.0. 0/0" - matches against any IP address. This field must contain at least one entry if the access type is EXTERNAL. The number of allowed CIDR blocks cannot exceed 500. Example: 192.168.0.0/16 Corresponds to the JSON property allowedCidrBlocks

Returns:

  • (Array<String>)


115
116
117
# File 'lib/google/apis/ftp_v1/classes.rb', line 115

def allowed_cidr_blocks
  @allowed_cidr_blocks
end

#ip_addressString

Output only. IP address of the LB via which clients will connect. Corresponds to the JSON property ipAddress

Returns:

  • (String)


120
121
122
# File 'lib/google/apis/ftp_v1/classes.rb', line 120

def ip_address
  @ip_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



127
128
129
130
# File 'lib/google/apis/ftp_v1/classes.rb', line 127

def update!(**args)
  @allowed_cidr_blocks = args[:allowed_cidr_blocks] if args.key?(:allowed_cidr_blocks)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
end