Class: Google::Apis::FtpV1::Server

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ftp_v1/classes.rb,
lib/google/apis/ftp_v1/representations.rb,
lib/google/apis/ftp_v1/representations.rb

Overview

Message describing Server object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Server

Returns a new instance of Server.



556
557
558
# File 'lib/google/apis/ftp_v1/classes.rb', line 556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_typeString

Required. The access type of the Server. Corresponds to the JSON property accessType

Returns:

  • (String)


504
505
506
# File 'lib/google/apis/ftp_v1/classes.rb', line 504

def access_type
  @access_type
end

#create_timeString

Output only. [Output only] Create time stamp Corresponds to the JSON property createTime

Returns:

  • (String)


509
510
511
# File 'lib/google/apis/ftp_v1/classes.rb', line 509

def create_time
  @create_time
end

#display_nameString

Optional. Display name of the Server Corresponds to the JSON property displayName

Returns:

  • (String)


514
515
516
# File 'lib/google/apis/ftp_v1/classes.rb', line 514

def display_name
  @display_name
end

#external_configGoogle::Apis::FtpV1::ExternalServerConfig

Configuration for external server. Corresponds to the JSON property externalConfig



519
520
521
# File 'lib/google/apis/ftp_v1/classes.rb', line 519

def external_config
  @external_config
end

#google_managed_server_credentialGoogle::Apis::FtpV1::ServerCredential

Represents credentials of an FTP Server. Corresponds to the JSON property googleManagedServerCredential



524
525
526
# File 'lib/google/apis/ftp_v1/classes.rb', line 524

def google_managed_server_credential
  @google_managed_server_credential
end

#internal_configGoogle::Apis::FtpV1::InternalServerConfig

Configuration for private server accessible via PSC. Corresponds to the JSON property internalConfig



529
530
531
# File 'lib/google/apis/ftp_v1/classes.rb', line 529

def internal_config
  @internal_config
end

#labelsHash<String,String>

Optional. Labels as key value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


534
535
536
# File 'lib/google/apis/ftp_v1/classes.rb', line 534

def labels
  @labels
end

#nameString

Identifier. name of resource Corresponds to the JSON property name

Returns:

  • (String)


539
540
541
# File 'lib/google/apis/ftp_v1/classes.rb', line 539

def name
  @name
end

#service_agentString

Output only. Service agent used to access the customer bucket. Corresponds to the JSON property serviceAgent

Returns:

  • (String)


544
545
546
# File 'lib/google/apis/ftp_v1/classes.rb', line 544

def service_agent
  @service_agent
end

#stateString

Output only. The state of the server. Corresponds to the JSON property state

Returns:

  • (String)


549
550
551
# File 'lib/google/apis/ftp_v1/classes.rb', line 549

def state
  @state
end

#update_timeString

Output only. [Output only] Update time stamp Corresponds to the JSON property updateTime

Returns:

  • (String)


554
555
556
# File 'lib/google/apis/ftp_v1/classes.rb', line 554

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'lib/google/apis/ftp_v1/classes.rb', line 561

def update!(**args)
  @access_type = args[:access_type] if args.key?(:access_type)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @external_config = args[:external_config] if args.key?(:external_config)
  @google_managed_server_credential = args[:google_managed_server_credential] if args.key?(:google_managed_server_credential)
  @internal_config = args[:internal_config] if args.key?(:internal_config)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service_agent = args[:service_agent] if args.key?(:service_agent)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end