Class: Google::Apis::FtpV1::ServerCredential

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ftp_v1/classes.rb,
lib/google/apis/ftp_v1/representations.rb,
lib/google/apis/ftp_v1/representations.rb

Overview

Represents credentials of an FTP Server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServerCredential

Returns a new instance of ServerCredential.



593
594
595
# File 'lib/google/apis/ftp_v1/classes.rb', line 593

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asymmetric_algorithmString

Output only. Asymmetric algorithm used by the public key. Possible values (can be expanded in future): - ssh-ed25519 Corresponds to the JSON property asymmetricAlgorithm

Returns:

  • (String)


584
585
586
# File 'lib/google/apis/ftp_v1/classes.rb', line 584

def asymmetric_algorithm
  @asymmetric_algorithm
end

#fingerprintString

Output only. The fingerprint is a hash of the public key, and is displayed when clients access the server for the first time to verify the server's identity. Corresponds to the JSON property fingerprint

Returns:

  • (String)


591
592
593
# File 'lib/google/apis/ftp_v1/classes.rb', line 591

def fingerprint
  @fingerprint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



598
599
600
601
# File 'lib/google/apis/ftp_v1/classes.rb', line 598

def update!(**args)
  @asymmetric_algorithm = args[:asymmetric_algorithm] if args.key?(:asymmetric_algorithm)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
end