Class: Google::Apis::FtpV1::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ftp_v1/classes.rb,
lib/google/apis/ftp_v1/representations.rb,
lib/google/apis/ftp_v1/representations.rb

Overview

Message describing User object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



767
768
769
# File 'lib/google/apis/ftp_v1/classes.rb', line 767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. [Output only] Create time stamp Corresponds to the JSON property createTime

Returns:

  • (String)


722
723
724
# File 'lib/google/apis/ftp_v1/classes.rb', line 722

def create_time
  @create_time
end

#customer_service_accountString

Required. Service account in customer project attached to this SFTP User. Corresponds to the JSON property customerServiceAccount

Returns:

  • (String)


727
728
729
# File 'lib/google/apis/ftp_v1/classes.rb', line 727

def 
  @customer_service_account
end

#labelsHash<String,String>

Optional. Labels as key value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


732
733
734
# File 'lib/google/apis/ftp_v1/classes.rb', line 732

def labels
  @labels
end

#nameString

Identifier. User-friendly name via which User will be identified. projects/ project/locations/location/servers/server/users/user Corresponds to the JSON property name

Returns:

  • (String)


738
739
740
# File 'lib/google/apis/ftp_v1/classes.rb', line 738

def name
  @name
end

#stateString

Output only. Tracks user creation. Corresponds to the JSON property state

Returns:

  • (String)


743
744
745
# File 'lib/google/apis/ftp_v1/classes.rb', line 743

def state
  @state
end

#storage_directory_mappingsArray<Google::Apis::FtpV1::StorageDirectoryMapping>

Required. Mapping of Cloud Storage buckets to directories where the user will land in the SFTP server. Corresponds to the JSON property storageDirectoryMappings



749
750
751
# File 'lib/google/apis/ftp_v1/classes.rb', line 749

def storage_directory_mappings
  @storage_directory_mappings
end

#update_timeString

Output only. [Output only] Update time stamp Corresponds to the JSON property updateTime

Returns:

  • (String)


754
755
756
# File 'lib/google/apis/ftp_v1/classes.rb', line 754

def update_time
  @update_time
end

#user_credentialsArray<Google::Apis::FtpV1::UserCredential>

Required. User credential for the user. The maximum number of user credentials is 10. Corresponds to the JSON property userCredentials



760
761
762
# File 'lib/google/apis/ftp_v1/classes.rb', line 760

def user_credentials
  @user_credentials
end

#usernameString

Output only. [Output only] The username of the user. Corresponds to the JSON property username

Returns:

  • (String)


765
766
767
# File 'lib/google/apis/ftp_v1/classes.rb', line 765

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



772
773
774
775
776
777
778
779
780
781
782
# File 'lib/google/apis/ftp_v1/classes.rb', line 772

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @customer_service_account = args[:customer_service_account] if args.key?(:customer_service_account)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @storage_directory_mappings = args[:storage_directory_mappings] if args.key?(:storage_directory_mappings)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_credentials = args[:user_credentials] if args.key?(:user_credentials)
  @username = args[:username] if args.key?(:username)
end