Class: Google::Apis::FtpV1::InternalServerConfig
- Inherits:
-
Object
- Object
- Google::Apis::FtpV1::InternalServerConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ftp_v1/classes.rb,
lib/google/apis/ftp_v1/representations.rb,
lib/google/apis/ftp_v1/representations.rb
Overview
Configuration for private server accessible via PSC.
Instance Attribute Summary collapse
-
#consumer_accept_list ⇒ Array<Google::Apis::FtpV1::AllowedConsumer>
Required.
-
#consumer_reject_list ⇒ Array<Google::Apis::FtpV1::DeniedConsumer>
Optional.
-
#psc_endpoints ⇒ Array<Google::Apis::FtpV1::PscEndpoint>
Output only.
-
#service_attachment ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InternalServerConfig
constructor
A new instance of InternalServerConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InternalServerConfig
Returns a new instance of InternalServerConfig.
162 163 164 |
# File 'lib/google/apis/ftp_v1/classes.rb', line 162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_accept_list ⇒ Array<Google::Apis::FtpV1::AllowedConsumer>
Required. A list of projects that are permitted to connect. At least one
project is required in the allow list.
Corresponds to the JSON property consumerAcceptList
141 142 143 |
# File 'lib/google/apis/ftp_v1/classes.rb', line 141 def consumer_accept_list @consumer_accept_list end |
#consumer_reject_list ⇒ Array<Google::Apis::FtpV1::DeniedConsumer>
Optional. A list of projects that are denied connection. Format: "projects/
sample_project_id" or "projects/1234567890" Projects in this list will be
denied access, even if they are included in the allow_list. If this list is
empty, no projects are explicitly rejected.
Corresponds to the JSON property consumerRejectList
149 150 151 |
# File 'lib/google/apis/ftp_v1/classes.rb', line 149 def consumer_reject_list @consumer_reject_list end |
#psc_endpoints ⇒ Array<Google::Apis::FtpV1::PscEndpoint>
Output only. Details of endpoints created by the customer.
Corresponds to the JSON property pscEndpoints
154 155 156 |
# File 'lib/google/apis/ftp_v1/classes.rb', line 154 def psc_endpoints @psc_endpoints end |
#service_attachment ⇒ String
Output only. The resource name of the service attachment. Format: projects/
project/regions/region/serviceAttachments/service_attachment`
Corresponds to the JSON propertyserviceAttachment`
160 161 162 |
# File 'lib/google/apis/ftp_v1/classes.rb', line 160 def @service_attachment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
167 168 169 170 171 172 |
# File 'lib/google/apis/ftp_v1/classes.rb', line 167 def update!(**args) @consumer_accept_list = args[:consumer_accept_list] if args.key?(:consumer_accept_list) @consumer_reject_list = args[:consumer_reject_list] if args.key?(:consumer_reject_list) @psc_endpoints = args[:psc_endpoints] if args.key?(:psc_endpoints) @service_attachment = args[:service_attachment] if args.key?(:service_attachment) end |