Class: Google::Apis::FtpV1::StorageDirectoryMapping
- Inherits:
-
Object
- Object
- Google::Apis::FtpV1::StorageDirectoryMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ftp_v1/classes.rb,
lib/google/apis/ftp_v1/representations.rb,
lib/google/apis/ftp_v1/representations.rb
Overview
Mapping of backing Cloud Storage path to the directory where the user lands in the SFTP server. If directory is not specified, it'll default to '/'. Eg 1 - ( bucket_name: bucket, bucket_prefix: path1/path2, directory: /abc/def/username) The user will land at /abcd/def/username, and the view there will match that of /bucket/path1/path2. The user will not be aware of Cloud Storage prefix '/ bucket/path1' and there will be no such directory in the view. Eg 2 - ( bucket_name: bucket, bucket_prefix: path1/path2, directory: '') The user will land at '/', and the view there will match that of /bucket/path1/path2. The user will not be aware of Cloud Storage prefix '/bucket/path1/path2' and there will be no such directory in the view.
Instance Attribute Summary collapse
-
#bucket ⇒ String
Required.
-
#bucket_prefix ⇒ String
Optional.
-
#directory ⇒ String
Required.
-
#permission ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDirectoryMapping
constructor
A new instance of StorageDirectoryMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDirectoryMapping
Returns a new instance of StorageDirectoryMapping.
702 703 704 |
# File 'lib/google/apis/ftp_v1/classes.rb', line 702 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket ⇒ String
Required. Name of the bucket.
Corresponds to the JSON property bucket
685 686 687 |
# File 'lib/google/apis/ftp_v1/classes.rb', line 685 def bucket @bucket end |
#bucket_prefix ⇒ String
Optional. Prefix inside the bucket.
Corresponds to the JSON property bucketPrefix
690 691 692 |
# File 'lib/google/apis/ftp_v1/classes.rb', line 690 def bucket_prefix @bucket_prefix end |
#directory ⇒ String
Required. Directory where the user lands in the SFTP server.
Corresponds to the JSON property directory
695 696 697 |
# File 'lib/google/apis/ftp_v1/classes.rb', line 695 def directory @directory end |
#permission ⇒ String
Required. Permission to the bucket.
Corresponds to the JSON property permission
700 701 702 |
# File 'lib/google/apis/ftp_v1/classes.rb', line 700 def @permission end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
707 708 709 710 711 712 |
# File 'lib/google/apis/ftp_v1/classes.rb', line 707 def update!(**args) @bucket = args[:bucket] if args.key?(:bucket) @bucket_prefix = args[:bucket_prefix] if args.key?(:bucket_prefix) @directory = args[:directory] if args.key?(:directory) @permission = args[:permission] if args.key?(:permission) end |